


# PP plots
See pp


# Monte carlo integration

* ``test_mcsampler_foridiots.py``: easy-to-read test code, not that stringent.

* ``test_mcsamplerEnsemble_extended.py`` : best single-contact test.  3d gaussian integration, with plot of recovered CDF.

* ``test_mcsampler_rosenbrock``: Simple 2d test
